@@ -59,6 +59,7 @@ class _RepackModelStep(TrainingStep):
         entry_point: str,
         source_dir: str = None,
         dependencies: List = None,
+        depends_on: List[str] = None,
     ):
         """Constructs a TrainingStep, given an `EstimatorBase` instance.
 
@@ -102,7 +103,9 @@ class _RepackModelStep(TrainingStep):
         inputs = TrainingInput(self._model_prefix)
 
         # super!
-        super(_RepackModelStep, self).__init__(name=name, estimator=repacker, inputs=inputs)
+        super(_RepackModelStep, self).__init__(
+            name=name, depends_on=depends_on, estimator=repacker, inputs=inputs
+        )
 
     def _prepare_for_repacking(self):
         """Prepares the source for the estimator."""
@@ -221,6 +224,7 @@ class _RegisterModelStep(Step):
         image_uri=None,
         compile_model_family=None,
         description=None,
+        depends_on: List[str] = None,
         **kwargs,
     ):
         """Constructor of a register model step.
@@ -248,9 +252,11 @@ class _RegisterModelStep(Step):
             compile_model_family (str): Instance family for compiled model, if specified, a compiled
                 model will be used (default: None).
             description (str): Model Package description (default: None).
+            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.TrainingStep`
+                depends on
             **kwargs: additional arguments to `create_model`.
         """
-        super(_RegisterModelStep, self).__init__(name, StepTypeEnum.REGISTER_MODEL)
+        super(_RegisterModelStep, self).__init__(name, StepTypeEnum.REGISTER_MODEL, depends_on)
         self.estimator = estimator
         self.model_data = model_data
         self.content_types = content_types
