@@ -63,10 +63,12 @@ class Step(Entity):
     Attributes:
         name (str): The name of the step.
         step_type (StepTypeEnum): The type of the step.
+        depends_on (List[str]): The list of step names the current step depends on
     """
 
     name: str = attr.ib(factory=str)
     step_type: StepTypeEnum = attr.ib(factory=StepTypeEnum.factory)
+    depends_on: List[str] = attr.ib(default=None)
 
     @property
     @abc.abstractmethod
@@ -80,11 +82,22 @@ class Step(Entity):
 
     def to_request(self) -> RequestType:
         """Gets the request structure for workflow service calls."""
-        return {
+        request_dict = {
             "Name": self.name,
             "Type": self.step_type.value,
             "Arguments": self.arguments,
         }
+        if self.depends_on:
+            request_dict["DependsOn"] = self.depends_on
+        return request_dict
+
+    def add_depends_on(self, step_names: List[str]):
+        """Add step names to the current step depends on list"""
+        if not step_names:
+            return
+        if not self.depends_on:
+            self.depends_on = []
+        self.depends_on.extend(step_names)
 
     @property
     def ref(self) -> Dict[str, str]:
@@ -133,6 +146,7 @@ class TrainingStep(Step):
         estimator: EstimatorBase,
         inputs: TrainingInput = None,
         cache_config: CacheConfig = None,
+        depends_on: List[str] = None,
     ):
         """Construct a TrainingStep, given an `EstimatorBase` instance.
 
@@ -144,8 +158,10 @@ class TrainingStep(Step):
             estimator (EstimatorBase): A `sagemaker.estimator.EstimatorBase` instance.
             inputs (TrainingInput): A `sagemaker.inputs.TrainingInput` instance. Defaults to `None`.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
+            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.TrainingStep`
+                depends on
         """
-        super(TrainingStep, self).__init__(name, StepTypeEnum.TRAINING)
+        super(TrainingStep, self).__init__(name, StepTypeEnum.TRAINING, depends_on)
         self.estimator = estimator
         self.inputs = inputs
         self._properties = Properties(
@@ -188,10 +204,7 @@ class CreateModelStep(Step):
     """CreateModel step for workflow."""
 
     def __init__(
-        self,
-        name: str,
-        model: Model,
-        inputs: CreateModelInput,
+        self, name: str, model: Model, inputs: CreateModelInput, depends_on: List[str] = None
     ):
         """Construct a CreateModelStep, given an `sagemaker.model.Model` instance.
 
@@ -203,8 +216,10 @@ class CreateModelStep(Step):
             model (Model): A `sagemaker.model.Model` instance.
             inputs (CreateModelInput): A `sagemaker.inputs.CreateModelInput` instance.
                 Defaults to `None`.
+            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.CreateModelStep`
+                depends on
         """
-        super(CreateModelStep, self).__init__(name, StepTypeEnum.CREATE_MODEL)
+        super(CreateModelStep, self).__init__(name, StepTypeEnum.CREATE_MODEL, depends_on)
         self.model = model
         self.inputs = inputs or CreateModelInput()
 
@@ -247,6 +262,7 @@ class TransformStep(Step):
         transformer: Transformer,
         inputs: TransformInput,
         cache_config: CacheConfig = None,
+        depends_on: List[str] = None,
     ):
         """Constructs a TransformStep, given an `Transformer` instance.
 
@@ -258,8 +274,10 @@ class TransformStep(Step):
             transformer (Transformer): A `sagemaker.transformer.Transformer` instance.
             inputs (TransformInput): A `sagemaker.inputs.TransformInput` instance.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
+            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.TransformStep`
+                depends on
         """
-        super(TransformStep, self).__init__(name, StepTypeEnum.TRANSFORM)
+        super(TransformStep, self).__init__(name, StepTypeEnum.TRANSFORM, depends_on)
         self.transformer = transformer
         self.inputs = inputs
         self.cache_config = cache_config
@@ -320,6 +338,7 @@ class ProcessingStep(Step):
         code: str = None,
         property_files: List[PropertyFile] = None,
         cache_config: CacheConfig = None,
+        depends_on: List[str] = None,
     ):
         """Construct a ProcessingStep, given a `Processor` instance.
 
@@ -340,8 +359,10 @@ class ProcessingStep(Step):
             property_files (List[PropertyFile]): A list of property files that workflow looks
                 for and resolves from the configured processing output list.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
+            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.ProcessingStep`
+                depends on
         """
-        super(ProcessingStep, self).__init__(name, StepTypeEnum.PROCESSING)
+        super(ProcessingStep, self).__init__(name, StepTypeEnum.PROCESSING, depends_on)
         self.processor = processor
         self.inputs = inputs
         self.outputs = outputs
